@@ -284,12 +284,6 @@ public:
      * @param convId
      */
     void clearInteractionsCache(const QString& convId);
-    /**
-     * Retry to send a message. In fact, will delete the previous interaction and resend a new one.
-     * @param convId
-     * @param interactionId
-     */
-    void retryInteraction(const QString& convId, const QString& interactionId);
     /**
      * @param convId
      * @param interactionId
@@ -305,7 +299,10 @@ public:
      */
     void deleteObsoleteHistory(int date);
 
-    void sendFile(const QString& convUid, const QString& path, const QString& filename);
+    void sendFile(const QString& convUid,
+                  const QString& path,
+                  const QString& filename,
+                  const QString& parent);
 
     void acceptTransfer(const QString& convUid, const QString& interactionId);
 
@@ -316,9 +313,12 @@ public:
                          api::datatransfer::Info& info) const;
 
     /**
-     * Starts a search of all medias and files in a conversation
+     * Starts a search of all medias in a conversation
      */
-    void getConvMediasInfos(const QString& accountId, const QString& conversationId);
+    void getConvMediasInfos(const QString& accountId,
+                            const QString& conversationId,
+                            const QString& text,
+                            bool isMedia);
     /**
      * @param convUid, uid of the conversation
      * @return the number of unread messages for the conversation
@@ -371,8 +371,9 @@ public:
      * create a new swarm conversation
      * @param participants  conversation's participants
      * @param infos conversation's infos
+     * @return new conversation id
      */
-    void createConversation(const VectorString& participants, const MapStringString& infos = {});
+    QString createConversation(const VectorString& participants, const MapStringString& infos = {});
     /**
      * update conversation info
      * @param conversationId conversation's id
@@ -612,12 +613,10 @@ Q_SIGNALS:
     /**
      * Emitted once a message search has been done and processed
      * @param accountId
-     * @param messageIds ids of all the messages found by the search
-     * @param messageInformations message datas
+     * @param messageInformation message datas
      */
     void messagesFoundProcessed(const QString& accountId,
-                                const VectorMapStringString& messageIds,
-                                const QVector<interaction::Info>& messageInformations) const;
+                                const QMap<QString, interaction::Info>& messageInformation) const;
     /**
      * Emitted once a conversation needs somebody to host the call
      * @param callId
